/*******************************************************************************
* File Name: Comp_Sensor.c
* Version 1.0
*
* Description:
*  This file provides the power management source code APIs for the
*  Comparator.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Comp_Sensor.h"


static Comp_Sensor_BACKUP_STRUCT Comp_Sensor_backup;


/*******************************************************************************
* Function Name: Comp_Sensor_SaveConfig
********************************************************************************
*
* Summary:
*  Save the current user configuration
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Comp_Sensor_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: Comp_Sensor_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
********************************************************************************/
void Comp_Sensor_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: Comp_Sensor_Sleep
********************************************************************************
*
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Comp_Sensor_backup.enableState:  Is modified depending on the enable
*   state of the block before entering sleep mode.
*
*******************************************************************************/
void Comp_Sensor_Sleep(void)
{
    if(0u != (Comp_Sensor_OA_CTRL_REG & Comp_Sensor_OA_PWR_MODE_HIGH))
    {
        Comp_Sensor_backup.enableState = 1u;
    }
    else /* The TMP05 block is disabled */
    {
        Comp_Sensor_backup.enableState = 0u;
    }

    Comp_Sensor_Stop();
    Comp_Sensor_SaveConfig();
}


/*******************************************************************************
* Function Name: Comp_Sensor_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Comp_Sensor_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Comp_Sensor_Wakeup(void)
{
    Comp_Sensor_RestoreConfig();

    if(Comp_Sensor_backup.enableState == 1u)
    {
        /* Enable Comp's operation */
        Comp_Sensor_Enable();
    } /* Do nothing if Comp was disabled before */
}


/* [] END OF FILE */

