/*******************************************************************************
* File Name: IDAC_ComparatorVref.c
* Version 1.0
*
* Description:
*  This file provides the source code of APIs for the IDAC_P4 component.
*
*******************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "IDAC_ComparatorVref.h"

uint32 IDAC_ComparatorVref_initVar = 0u;


/*******************************************************************************
* Function Name: IDAC_ComparatorVref_Init
********************************************************************************
*
* Summary:
*  Initializes IDAC registers with initial values provided from customizer.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  None
*
*******************************************************************************/
void IDAC_ComparatorVref_Init(void)
{
    uint8 enableInterrupts;

    /* Set initial configuration */
    enableInterrupts = CyEnterCriticalSection();

    /* clear previous values */
    IDAC_ComparatorVref_IDAC_CONTROL_REG &= ((uint32)~((uint32)IDAC_ComparatorVref_IDAC_VALUE_MASK <<
        IDAC_ComparatorVref_IDAC_VALUE_POSITION)) | ((uint32)~((uint32)IDAC_ComparatorVref_IDAC_MODE_MASK <<
        IDAC_ComparatorVref_IDAC_MODE_POSITION))  | ((uint32)~((uint32)IDAC_ComparatorVref_IDAC_RANGE_MASK  <<
        IDAC_ComparatorVref_IDAC_RANGE_POSITION));

    IDAC_ComparatorVref_IDAC_POLARITY_CONTROL_REG &= (~(uint32)((uint32)IDAC_ComparatorVref_IDAC_POLARITY_MASK <<
        IDAC_ComparatorVref_IDAC_POLARITY_POSITION));

    /* set new configuration */
    IDAC_ComparatorVref_IDAC_CONTROL_REG |= (((uint32)IDAC_ComparatorVref_IDAC_INIT_VALUE <<
        IDAC_ComparatorVref_IDAC_VALUE_POSITION) | ((uint32)IDAC_ComparatorVref_IDAC_RANGE <<
        IDAC_ComparatorVref_IDAC_RANGE_POSITION));

    IDAC_ComparatorVref_IDAC_POLARITY_CONTROL_REG |= ((uint32)IDAC_ComparatorVref_IDAC_POLARITY <<
                                                           IDAC_ComparatorVref_IDAC_POLARITY_POSITION);

    CyExitCriticalSection(enableInterrupts);

}


/*******************************************************************************
* Function Name: IDAC_ComparatorVref_Enable
********************************************************************************
*
* Summary:
*  Enables IDAC operations.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  None
*
*******************************************************************************/
void IDAC_ComparatorVref_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    /* Enable the IDAC */
    IDAC_ComparatorVref_IDAC_CONTROL_REG |= ((uint32)IDAC_ComparatorVref_IDAC_EN_MODE <<
                                                  IDAC_ComparatorVref_IDAC_MODE_POSITION);
    IDAC_ComparatorVref_IDAC_POLARITY_CONTROL_REG |= ((uint32)IDAC_ComparatorVref_IDAC_CSD_EN <<
                                                           IDAC_ComparatorVref_IDAC_CSD_EN_POSITION);
    CyExitCriticalSection(enableInterrupts);

}


/*******************************************************************************
* Function Name: IDAC_ComparatorVref_Start
********************************************************************************
*
* Summary:
*  Starts the IDAC hardware.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  IDAC_ComparatorVref_initVar
*
*******************************************************************************/
void IDAC_ComparatorVref_Start(void)
{
    if(0u == IDAC_ComparatorVref_initVar)
    {
        IDAC_ComparatorVref_Init();
        IDAC_ComparatorVref_initVar = 1u;
    }

    IDAC_ComparatorVref_Enable();

}


/*******************************************************************************
* Function Name: IDAC_ComparatorVref_Stop
********************************************************************************
*
* Summary:
*  Stops the IDAC hardware.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  None
*
*******************************************************************************/
void IDAC_ComparatorVref_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    /* Disable the IDAC */
    IDAC_ComparatorVref_IDAC_CONTROL_REG &= ((uint32)~((uint32)IDAC_ComparatorVref_IDAC_MODE_MASK <<
        IDAC_ComparatorVref_IDAC_MODE_POSITION));
    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: IDAC_ComparatorVref_SetValue
********************************************************************************
*
* Summary:
*  Sets the IDAC value.
*
* Parameters:
*  uint32 value
*
* Return:
*  None
*
* Global variables:
*  None
*
*******************************************************************************/
void IDAC_ComparatorVref_SetValue(uint32 value)
{
    uint8 enableInterrupts;
    uint32 newRegisterValue;

    enableInterrupts = CyEnterCriticalSection();

    #if(IDAC_ComparatorVref_IDAC_VALUE_POSITION != 0u)
        newRegisterValue = ((IDAC_ComparatorVref_IDAC_CONTROL_REG & (~(uint32)((uint32)IDAC_ComparatorVref_IDAC_VALUE_MASK <<
        IDAC_ComparatorVref_IDAC_VALUE_POSITION))) | (value << IDAC_ComparatorVref_IDAC_VALUE_POSITION));
    #else
        newRegisterValue = ((IDAC_ComparatorVref_IDAC_CONTROL_REG & (~(uint32)IDAC_ComparatorVref_IDAC_VALUE_MASK)) | value);
    #endif /* IDAC_ComparatorVref_IDAC_VALUE_POSITION != 0u */

    IDAC_ComparatorVref_IDAC_CONTROL_REG = newRegisterValue;

    CyExitCriticalSection(enableInterrupts);
}

/* [] END OF FILE */
