/*******************************************************************************
* File Name: Opamp_Gain_PM.c
* Version 1.0
*
* Description:
*  This file provides the power management source code to the API for the
*  OpAmp (Analog Buffer) component.
*
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Opamp_Gain.h"

static Opamp_Gain_BACKUP_STRUCT  Opamp_Gain_backup;


/*******************************************************************************
* Function Name: Opamp_Gain_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration registers.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Opamp_Gain_SaveConfig(void)
{
}


/*******************************************************************************
* Function Name: Opamp_Gain_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration registers.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Opamp_Gain_RestoreConfig(void)
{
}


/*******************************************************************************
* Function Name: Opamp_Gain_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Opamp_Gain_backup: The structure field 'enableState' is modified
*  depending on the enable state of the block before entering to sleep mode.
*
*******************************************************************************/
void Opamp_Gain_Sleep(void)
{
    /* Save OpAmp enable state */
    if((Opamp_Gain_OA_RES_CTRL & Opamp_Gain_OA_PWR_MODE_MASK) != 0u)
    {
        /* Component is enabled */
        Opamp_Gain_backup.enableState = 1u;
        /* Stops the component */
        Opamp_Gain_Stop();
    }
    else
    {
        /* Component is disabled */
        Opamp_Gain_backup.enableState = 0u;
    }
    /* Saves the configuration */
    Opamp_Gain_SaveConfig();
}


/*******************************************************************************
* Function Name: Opamp_Gain_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  Opamp_Gain_backup: The structure field 'enableState' is used to
*  restore the enable state of block after wakeup from sleep mode.
*
*******************************************************************************/
void Opamp_Gain_Wakeup(void)
{
    /* Restore the user configuration */
    Opamp_Gain_RestoreConfig();

    /* Enables the component operation */
    if(Opamp_Gain_backup.enableState == 1u)
    {
        Opamp_Gain_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
