/*******************************************************************************
* File Name: PWM_Right_PM.c
* Version 1.0
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PWM_Right.h"

static PWM_Right_BACKUP_STRUCT PWM_Right_backup;


/*******************************************************************************
* Function Name: PWM_Right_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Right_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: PWM_Right_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Right_Sleep(void)
{
    if(0u != (PWM_Right_BLOCK_CONTROL_REG & PWM_Right_MASK))
    {
        PWM_Right_backup.enableState = 1u;
    }
    else
    {
        PWM_Right_backup.enableState = 0u;
    }

    PWM_Right_Stop();
    PWM_Right_SaveConfig();
}


/*******************************************************************************
* Function Name: PWM_Right_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Right_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: PWM_Right_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWM_Right_Wakeup(void)
{
    PWM_Right_RestoreConfig();

    if(0u != PWM_Right_backup.enableState)
    {
        PWM_Right_Enable();
    }
}


/* [] END OF FILE */
